# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregates_spot_exchange_rate_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/aggregates_spot_exchange_rate_v1/request.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n5com.kaiko.sdk.stream.aggregates_spot_exchange_rate_v1P\001Zogithub.com/challengerdeep/kaiko-go-sdk/stream/aggregates_spot_exchange_rate_v1;aggregates_spot_exchange_rate_v1\252\002,KaikoSdk.Stream.AggregatesSpotExchangeRateV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9sdk/stream/aggregates_spot_exchange_rate_v1/request.proto\x12\x08kaikosdk\"]\n)StreamAggregatesSpotExchangeRateRequestV1\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x11\n\taggregate\x18\x02 \x01(\t\x12\x0f\n\x07sources\x18\x03 \x01(\x08\x42\xd9\x01\n5com.kaiko.sdk.stream.aggregates_spot_exchange_rate_v1P\x01Zogithub.com/challengerdeep/kaiko-go-sdk/stream/aggregates_spot_exchange_rate_v1;aggregates_spot_exchange_rate_v1\xaa\x02,KaikoSdk.Stream.AggregatesSpotExchangeRateV1b\x06proto3'
)




_STREAMAGGREGATESSPOTEXCHANGERATEREQUESTV1 = _descriptor.Descriptor(
  name='StreamAggregatesSpotExchangeRateRequestV1',
  full_name='kaikosdk.StreamAggregatesSpotExchangeRateRequestV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='kaikosdk.StreamAggregatesSpotExchangeRateRequestV1.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregate', full_name='kaikosdk.StreamAggregatesSpotExchangeRateRequestV1.aggregate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sources', full_name='kaikosdk.StreamAggregatesSpotExchangeRateRequestV1.sources', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=164,
)

DESCRIPTOR.message_types_by_name['StreamAggregatesSpotExchangeRateRequestV1'] = _STREAMAGGREGATESSPOTEXCHANGERATEREQUESTV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamAggregatesSpotExchangeRateRequestV1 = _reflection.GeneratedProtocolMessageType('StreamAggregatesSpotExchangeRateRequestV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMAGGREGATESSPOTEXCHANGERATEREQUESTV1,
  '__module__' : 'sdk.stream.aggregates_spot_exchange_rate_v1.request_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamAggregatesSpotExchangeRateRequestV1)
  })
_sym_db.RegisterMessage(StreamAggregatesSpotExchangeRateRequestV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregates_ohlcv_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import instrument_criteria_pb2 as sdk_dot_core_dot_instrument__criteria__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/aggregates_ohlcv_v1/request.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n(com.kaiko.sdk.stream.aggregates_ohlcv_v1P\001ZUgithub.com/challengerdeep/kaiko-go-sdk/stream/aggregates_ohlcv_v1;aggregates_ohlcv_v1\252\002!KaikoSdk.Stream.AggregatesOHLCVV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,sdk/stream/aggregates_ohlcv_v1/request.proto\x12\x08kaikosdk\x1a\"sdk/core/instrument_criteria.proto\"n\n\x1eStreamAggregatesOHLCVRequestV1\x12\x39\n\x13instrument_criteria\x18\x01 \x01(\x0b\x32\x1c.kaikosdk.InstrumentCriteria\x12\x11\n\taggregate\x18\x02 \x01(\tB\xa7\x01\n(com.kaiko.sdk.stream.aggregates_ohlcv_v1P\x01ZUgithub.com/challengerdeep/kaiko-go-sdk/stream/aggregates_ohlcv_v1;aggregates_ohlcv_v1\xaa\x02!KaikoSdk.Stream.AggregatesOHLCVV1b\x06proto3'
  ,
  dependencies=[sdk_dot_core_dot_instrument__criteria__pb2.DESCRIPTOR,])




_STREAMAGGREGATESOHLCVREQUESTV1 = _descriptor.Descriptor(
  name='StreamAggregatesOHLCVRequestV1',
  full_name='kaikosdk.StreamAggregatesOHLCVRequestV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instrument_criteria', full_name='kaikosdk.StreamAggregatesOHLCVRequestV1.instrument_criteria', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregate', full_name='kaikosdk.StreamAggregatesOHLCVRequestV1.aggregate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=204,
)

_STREAMAGGREGATESOHLCVREQUESTV1.fields_by_name['instrument_criteria'].message_type = sdk_dot_core_dot_instrument__criteria__pb2._INSTRUMENTCRITERIA
DESCRIPTOR.message_types_by_name['StreamAggregatesOHLCVRequestV1'] = _STREAMAGGREGATESOHLCVREQUESTV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamAggregatesOHLCVRequestV1 = _reflection.GeneratedProtocolMessageType('StreamAggregatesOHLCVRequestV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMAGGREGATESOHLCVREQUESTV1,
  '__module__' : 'sdk.stream.aggregates_ohlcv_v1.request_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamAggregatesOHLCVRequestV1)
  })
_sym_db.RegisterMessage(StreamAggregatesOHLCVRequestV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/core/wrappers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/core/wrappers.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\022com.kaiko.sdk.coreP\001Z0github.com/challengerdeep/kaiko-go-sdk/core;core\252\002\rKaikoSdk.Core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17sdk/core/wrappers.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\";\n\x0eTimestampValue\x12)\n\x05value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampBX\n\x12\x63om.kaiko.sdk.coreP\x01Z0github.com/challengerdeep/kaiko-go-sdk/core;core\xaa\x02\rKaikoSdk.Coreb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_TIMESTAMPVALUE = _descriptor.Descriptor(
  name='TimestampValue',
  full_name='kaikosdk.TimestampValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='kaikosdk.TimestampValue.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=129,
)

_TIMESTAMPVALUE.fields_by_name['value'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['TimestampValue'] = _TIMESTAMPVALUE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimestampValue = _reflection.GeneratedProtocolMessageType('TimestampValue', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMPVALUE,
  '__module__' : 'sdk.core.wrappers_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.TimestampValue)
  })
_sym_db.RegisterMessage(TimestampValue)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/core/sort_criteria.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/core/sort_criteria.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\022com.kaiko.sdk.coreP\001Z0github.com/challengerdeep/kaiko-go-sdk/core;core\252\002\rKaikoSdk.Core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1csdk/core/sort_criteria.proto\x12\x08kaikosdk*3\n\x0cSortCriteria\x12\x10\n\x0cSORT_UNKNOWN\x10\x00\x12\x07\n\x03\x41SC\x10\x01\x12\x08\n\x04\x44\x45SC\x10\x02\x42X\n\x12\x63om.kaiko.sdk.coreP\x01Z0github.com/challengerdeep/kaiko-go-sdk/core;core\xaa\x02\rKaikoSdk.Coreb\x06proto3'
)

_SORTCRITERIA = _descriptor.EnumDescriptor(
  name='SortCriteria',
  full_name='kaikosdk.SortCriteria',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SORT_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DESC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=42,
  serialized_end=93,
)
_sym_db.RegisterEnumDescriptor(_SORTCRITERIA)

SortCriteria = enum_type_wrapper.EnumTypeWrapper(_SORTCRITERIA)
SORT_UNKNOWN = 0
ASC = 1
DESC = 2


DESCRIPTOR.enum_types_by_name['SortCriteria'] = _SORTCRITERIA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregates_ohlcv_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/aggregates_ohlcv_v1/response.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n(com.kaiko.sdk.stream.aggregates_ohlcv_v1P\001ZUgithub.com/challengerdeep/kaiko-go-sdk/stream/aggregates_ohlcv_v1;aggregates_ohlcv_v1\252\002!KaikoSdk.Stream.AggregatesOHLCVV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-sdk/stream/aggregates_ohlcv_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfc\x01\n\x1fStreamAggregatesOHLCVResponseV1\x12\x11\n\taggregate\x18\x01 \x01(\t\x12\r\n\x05\x63lass\x18\x02 \x01(\t\x12\r\n\x05\x63lose\x18\x03 \x01(\t\x12\x10\n\x08\x65xchange\x18\x04 \x01(\t\x12\x0c\n\x04high\x18\x05 \x01(\t\x12\x0b\n\x03low\x18\x06 \x01(\t\x12\x0c\n\x04open\x18\x07 \x01(\t\x12\x13\n\x0bsequence_id\x18\x08 \x01(\t\x12\x0c\n\x04\x63ode\x18\t \x01(\t\x12-\n\ttimestamp\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03uid\x18\x0b \x01(\t\x12\x0e\n\x06volume\x18\x0c \x01(\tB\xa7\x01\n(com.kaiko.sdk.stream.aggregates_ohlcv_v1P\x01ZUgithub.com/challengerdeep/kaiko-go-sdk/stream/aggregates_ohlcv_v1;aggregates_ohlcv_v1\xaa\x02!KaikoSdk.Stream.AggregatesOHLCVV1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_STREAMAGGREGATESOHLCVRESPONSEV1 = _descriptor.Descriptor(
  name='StreamAggregatesOHLCVResponseV1',
  full_name='kaikosdk.StreamAggregatesOHLCVResponseV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aggregate', full_name='kaikosdk.StreamAggregatesOHLCVResponseV1.aggregate', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class', full_name='kaikosdk.StreamAggregatesOHLCVResponseV1.class', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='kaikosdk.StreamAggregatesOHLCVResponseV1.close', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='kaikosdk.StreamAggregatesOHLCVResponseV1.exchange', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high', full_name='kaikosdk.StreamAggregatesOHLCVResponseV1.high', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low', full_name='kaikosdk.StreamAggregatesOHLCVResponseV1.low', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='kaikosdk.StreamAggregatesOHLCVResponseV1.open', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_id', full_name='kaikosdk.StreamAggregatesOHLCVResponseV1.sequence_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='kaikosdk.StreamAggregatesOHLCVResponseV1.code', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='kaikosdk.StreamAggregatesOHLCVResponseV1.timestamp', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='kaikosdk.StreamAggregatesOHLCVResponseV1.uid', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='kaikosdk.StreamAggregatesOHLCVResponseV1.volume', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=345,
)

_STREAMAGGREGATESOHLCVRESPONSEV1.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['StreamAggregatesOHLCVResponseV1'] = _STREAMAGGREGATESOHLCVRESPONSEV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamAggregatesOHLCVResponseV1 = _reflection.GeneratedProtocolMessageType('StreamAggregatesOHLCVResponseV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMAGGREGATESOHLCVRESPONSEV1,
  '__module__' : 'sdk.stream.aggregates_ohlcv_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamAggregatesOHLCVResponseV1)
  })
_sym_db.RegisterMessage(StreamAggregatesOHLCVResponseV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/index_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/index_v1/request.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\035com.kaiko.sdk.stream.index_v1P\001Z?github.com/challengerdeep/kaiko-go-sdk/stream/index_v1;index_v1\252\002\027KaikoSdk.Stream.IndexV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!sdk/stream/index_v1/request.proto\x12\x08kaikosdk\"E\n\x1bStreamIndexServiceRequestV1\x12\x12\n\nindex_code\x18\x01 \x01(\t\x12\x12\n\nevent_type\x18\x02 \x01(\tB|\n\x1d\x63om.kaiko.sdk.stream.index_v1P\x01Z?github.com/challengerdeep/kaiko-go-sdk/stream/index_v1;index_v1\xaa\x02\x17KaikoSdk.Stream.IndexV1b\x06proto3'
)




_STREAMINDEXSERVICEREQUESTV1 = _descriptor.Descriptor(
  name='StreamIndexServiceRequestV1',
  full_name='kaikosdk.StreamIndexServiceRequestV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index_code', full_name='kaikosdk.StreamIndexServiceRequestV1.index_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='kaikosdk.StreamIndexServiceRequestV1.event_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=116,
)

DESCRIPTOR.message_types_by_name['StreamIndexServiceRequestV1'] = _STREAMINDEXSERVICEREQUESTV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamIndexServiceRequestV1 = _reflection.GeneratedProtocolMessageType('StreamIndexServiceRequestV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINDEXSERVICEREQUESTV1,
  '__module__' : 'sdk.stream.index_v1.request_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamIndexServiceRequestV1)
  })
_sym_db.RegisterMessage(StreamIndexServiceRequestV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregates_spot_exchange_rate_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import source_pb2 as sdk_dot_core_dot_source__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/aggregates_spot_exchange_rate_v1/response.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n5com.kaiko.sdk.stream.aggregates_spot_exchange_rate_v1P\001Zogithub.com/challengerdeep/kaiko-go-sdk/stream/aggregates_spot_exchange_rate_v1;aggregates_spot_exchange_rate_v1\252\002,KaikoSdk.Stream.AggregatesSpotExchangeRateV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:sdk/stream/aggregates_spot_exchange_rate_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x15sdk/core/source.proto\"\xc3\x02\n*StreamAggregatesSpotExchangeRateResponseV1\x12\x11\n\taggregate\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\r\n\x05price\x18\x03 \x01(\t\x12\x13\n\x0bsequence_id\x18\x04 \x01(\t\x12R\n\x07sources\x18\x05 \x03(\x0b\x32\x41.kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.SourcesEntry\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03uid\x18\x07 \x01(\t\x1a@\n\x0cSourcesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.kaikosdk.Source:\x02\x38\x01\x42\xd9\x01\n5com.kaiko.sdk.stream.aggregates_spot_exchange_rate_v1P\x01Zogithub.com/challengerdeep/kaiko-go-sdk/stream/aggregates_spot_exchange_rate_v1;aggregates_spot_exchange_rate_v1\xaa\x02,KaikoSdk.Stream.AggregatesSpotExchangeRateV1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,sdk_dot_core_dot_source__pb2.DESCRIPTOR,])




_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1_SOURCESENTRY = _descriptor.Descriptor(
  name='SourcesEntry',
  full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.SourcesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.SourcesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.SourcesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=388,
  serialized_end=452,
)

_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1 = _descriptor.Descriptor(
  name='StreamAggregatesSpotExchangeRateResponseV1',
  full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aggregate', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.aggregate', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.price', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_id', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.sequence_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sources', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.sources', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.timestamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.uid', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1_SOURCESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=452,
)

_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1_SOURCESENTRY.fields_by_name['value'].message_type = sdk_dot_core_dot_source__pb2._SOURCE
_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1_SOURCESENTRY.containing_type = _STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1
_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1.fields_by_name['sources'].message_type = _STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1_SOURCESENTRY
_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['StreamAggregatesSpotExchangeRateResponseV1'] = _STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamAggregatesSpotExchangeRateResponseV1 = _reflection.GeneratedProtocolMessageType('StreamAggregatesSpotExchangeRateResponseV1', (_message.Message,), {

  'SourcesEntry' : _reflection.GeneratedProtocolMessageType('SourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1_SOURCESENTRY,
    '__module__' : 'sdk.stream.aggregates_spot_exchange_rate_v1.response_pb2'
    # @@protoc_insertion_point(class_scope:kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.SourcesEntry)
    })
  ,
  'DESCRIPTOR' : _STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1,
  '__module__' : 'sdk.stream.aggregates_spot_exchange_rate_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamAggregatesSpotExchangeRateResponseV1)
  })
_sym_db.RegisterMessage(StreamAggregatesSpotExchangeRateResponseV1)
_sym_db.RegisterMessage(StreamAggregatesSpotExchangeRateResponseV1.SourcesEntry)


DESCRIPTOR._options = None
_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1_SOURCESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/market_update_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import wrappers_pb2 as sdk_dot_core_dot_wrappers__pb2
from kaikosdk.stream.market_update_v1 import commodity_pb2 as sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/market_update_v1/response.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n%com.kaiko.sdk.stream.market_update_v1P\001ZOgithub.com/challengerdeep/kaiko-go-sdk/stream/market_update_v1;market_update_v1\252\002\036KaikoSdk.Stream.MarketUpdateV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*sdk/stream/market_update_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17sdk/core/wrappers.proto\x1a+sdk/stream/market_update_v1/commodity.proto\"\xae\x04\n\x1cStreamMarketUpdateResponseV1\x12\x38\n\tcommodity\x18\x01 \x01(\x0e\x32%.kaikosdk.StreamMarketUpdateCommodity\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\r\n\x05\x63lass\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x10\n\x08\x65xchange\x18\x05 \x01(\t\x12\x13\n\x0bsequence_id\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\r\n\x05price\x18\x08 \x01(\x01\x12-\n\x0bts_exchange\x18\t \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12/\n\rts_collection\x18\n \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12,\n\x08ts_event\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12R\n\x0bupdate_type\x18\x0c \x01(\x0e\x32=.kaikosdk.StreamMarketUpdateResponseV1.StreamMarketUpdateType\"\x82\x01\n\x16StreamMarketUpdateType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tTRADE_BUY\x10\x01\x12\x0e\n\nTRADE_SELL\x10\x02\x12\x0c\n\x08\x42\x45ST_ASK\x10\x03\x12\x0c\n\x08\x42\x45ST_BID\x10\x04\x12\x0f\n\x0bUPDATED_ASK\x10\x05\x12\x0f\n\x0bUPDATED_BID\x10\x06\x42\x9b\x01\n%com.kaiko.sdk.stream.market_update_v1P\x01ZOgithub.com/challengerdeep/kaiko-go-sdk/stream/market_update_v1;market_update_v1\xaa\x02\x1eKaikoSdk.Stream.MarketUpdateV1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,sdk_dot_core_dot_wrappers__pb2.DESCRIPTOR,sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2.DESCRIPTOR,])



_STREAMMARKETUPDATERESPONSEV1_STREAMMARKETUPDATETYPE = _descriptor.EnumDescriptor(
  name='StreamMarketUpdateType',
  full_name='kaikosdk.StreamMarketUpdateResponseV1.StreamMarketUpdateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRADE_BUY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRADE_SELL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEST_ASK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEST_BID', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATED_ASK', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATED_BID', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=588,
  serialized_end=718,
)
_sym_db.RegisterEnumDescriptor(_STREAMMARKETUPDATERESPONSEV1_STREAMMARKETUPDATETYPE)


_STREAMMARKETUPDATERESPONSEV1 = _descriptor.Descriptor(
  name='StreamMarketUpdateResponseV1',
  full_name='kaikosdk.StreamMarketUpdateResponseV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commodity', full_name='kaikosdk.StreamMarketUpdateResponseV1.commodity', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='kaikosdk.StreamMarketUpdateResponseV1.amount', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class', full_name='kaikosdk.StreamMarketUpdateResponseV1.class', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='kaikosdk.StreamMarketUpdateResponseV1.code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='kaikosdk.StreamMarketUpdateResponseV1.exchange', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_id', full_name='kaikosdk.StreamMarketUpdateResponseV1.sequence_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='kaikosdk.StreamMarketUpdateResponseV1.id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='kaikosdk.StreamMarketUpdateResponseV1.price', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_exchange', full_name='kaikosdk.StreamMarketUpdateResponseV1.ts_exchange', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_collection', full_name='kaikosdk.StreamMarketUpdateResponseV1.ts_collection', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_event', full_name='kaikosdk.StreamMarketUpdateResponseV1.ts_event', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_type', full_name='kaikosdk.StreamMarketUpdateResponseV1.update_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STREAMMARKETUPDATERESPONSEV1_STREAMMARKETUPDATETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=718,
)

_STREAMMARKETUPDATERESPONSEV1.fields_by_name['commodity'].enum_type = sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2._STREAMMARKETUPDATECOMMODITY
_STREAMMARKETUPDATERESPONSEV1.fields_by_name['ts_exchange'].message_type = sdk_dot_core_dot_wrappers__pb2._TIMESTAMPVALUE
_STREAMMARKETUPDATERESPONSEV1.fields_by_name['ts_collection'].message_type = sdk_dot_core_dot_wrappers__pb2._TIMESTAMPVALUE
_STREAMMARKETUPDATERESPONSEV1.fields_by_name['ts_event'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMMARKETUPDATERESPONSEV1.fields_by_name['update_type'].enum_type = _STREAMMARKETUPDATERESPONSEV1_STREAMMARKETUPDATETYPE
_STREAMMARKETUPDATERESPONSEV1_STREAMMARKETUPDATETYPE.containing_type = _STREAMMARKETUPDATERESPONSEV1
DESCRIPTOR.message_types_by_name['StreamMarketUpdateResponseV1'] = _STREAMMARKETUPDATERESPONSEV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamMarketUpdateResponseV1 = _reflection.GeneratedProtocolMessageType('StreamMarketUpdateResponseV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMMARKETUPDATERESPONSEV1,
  '__module__' : 'sdk.stream.market_update_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamMarketUpdateResponseV1)
  })
_sym_db.RegisterMessage(StreamMarketUpdateResponseV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/trades_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import instrument_criteria_pb2 as sdk_dot_core_dot_instrument__criteria__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/trades_v1/request.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\036com.kaiko.sdk.stream.trades_v1P\001ZAgithub.com/challengerdeep/kaiko-go-sdk/stream/trades_v1;trades_v1\252\002\030KaikoSdk.Stream.TradesV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"sdk/stream/trades_v1/request.proto\x12\x08kaikosdk\x1a\"sdk/core/instrument_criteria.proto\"R\n\x15StreamTradesRequestV1\x12\x39\n\x13instrument_criteria\x18\x01 \x01(\x0b\x32\x1c.kaikosdk.InstrumentCriteriaB\x80\x01\n\x1e\x63om.kaiko.sdk.stream.trades_v1P\x01ZAgithub.com/challengerdeep/kaiko-go-sdk/stream/trades_v1;trades_v1\xaa\x02\x18KaikoSdk.Stream.TradesV1b\x06proto3'
  ,
  dependencies=[sdk_dot_core_dot_instrument__criteria__pb2.DESCRIPTOR,])




_STREAMTRADESREQUESTV1 = _descriptor.Descriptor(
  name='StreamTradesRequestV1',
  full_name='kaikosdk.StreamTradesRequestV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instrument_criteria', full_name='kaikosdk.StreamTradesRequestV1.instrument_criteria', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=166,
)

_STREAMTRADESREQUESTV1.fields_by_name['instrument_criteria'].message_type = sdk_dot_core_dot_instrument__criteria__pb2._INSTRUMENTCRITERIA
DESCRIPTOR.message_types_by_name['StreamTradesRequestV1'] = _STREAMTRADESREQUESTV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamTradesRequestV1 = _reflection.GeneratedProtocolMessageType('StreamTradesRequestV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTRADESREQUESTV1,
  '__module__' : 'sdk.stream.trades_v1.request_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamTradesRequestV1)
  })
_sym_db.RegisterMessage(StreamTradesRequestV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/sdk.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.stream.aggregates_ohlcv_v1 import request_pb2 as sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_request__pb2
from kaikosdk.stream.aggregates_ohlcv_v1 import response_pb2 as sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_response__pb2
from kaikosdk.stream.aggregates_vwap_v1 import request_pb2 as sdk_dot_stream_dot_aggregates__vwap__v1_dot_request__pb2
from kaikosdk.stream.aggregates_vwap_v1 import response_pb2 as sdk_dot_stream_dot_aggregates__vwap__v1_dot_response__pb2
from kaikosdk.stream.aggregates_direct_exchange_rate_v1 import request_pb2 as sdk_dot_stream_dot_aggregates__direct__exchange__rate__v1_dot_request__pb2
from kaikosdk.stream.aggregates_direct_exchange_rate_v1 import response_pb2 as sdk_dot_stream_dot_aggregates__direct__exchange__rate__v1_dot_response__pb2
from kaikosdk.stream.aggregates_spot_exchange_rate_v1 import request_pb2 as sdk_dot_stream_dot_aggregates__spot__exchange__rate__v1_dot_request__pb2
from kaikosdk.stream.aggregates_spot_exchange_rate_v1 import response_pb2 as sdk_dot_stream_dot_aggregates__spot__exchange__rate__v1_dot_response__pb2
from kaikosdk.stream.index_v1 import request_pb2 as sdk_dot_stream_dot_index__v1_dot_request__pb2
from kaikosdk.stream.index_v1 import response_pb2 as sdk_dot_stream_dot_index__v1_dot_response__pb2
from kaikosdk.stream.market_update_v1 import request_pb2 as sdk_dot_stream_dot_market__update__v1_dot_request__pb2
from kaikosdk.stream.market_update_v1 import response_pb2 as sdk_dot_stream_dot_market__update__v1_dot_response__pb2
from kaikosdk.stream.trades_v1 import request_pb2 as sdk_dot_stream_dot_trades__v1_dot_request__pb2
from kaikosdk.stream.trades_v1 import response_pb2 as sdk_dot_stream_dot_trades__v1_dot_response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/sdk.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\rcom.kaiko.sdkB\010SdkProtoP\001Z/github.com/challengerdeep/kaiko-go-sdk;kaikosdk\252\002\010KaikoSdk',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rsdk/sdk.proto\x12\x08kaikosdk\x1a,sdk/stream/aggregates_ohlcv_v1/request.proto\x1a-sdk/stream/aggregates_ohlcv_v1/response.proto\x1a+sdk/stream/aggregates_vwap_v1/request.proto\x1a,sdk/stream/aggregates_vwap_v1/response.proto\x1a;sdk/stream/aggregates_direct_exchange_rate_v1/request.proto\x1a<sdk/stream/aggregates_direct_exchange_rate_v1/response.proto\x1a\x39sdk/stream/aggregates_spot_exchange_rate_v1/request.proto\x1a:sdk/stream/aggregates_spot_exchange_rate_v1/response.proto\x1a!sdk/stream/index_v1/request.proto\x1a\"sdk/stream/index_v1/response.proto\x1a)sdk/stream/market_update_v1/request.proto\x1a*sdk/stream/market_update_v1/response.proto\x1a\"sdk/stream/trades_v1/request.proto\x1a#sdk/stream/trades_v1/response.proto2\x86\x01\n\x1eStreamAggregatesOHLCVServiceV1\x12\x64\n\tSubscribe\x12(.kaikosdk.StreamAggregatesOHLCVRequestV1\x1a).kaikosdk.StreamAggregatesOHLCVResponseV1\"\x00\x30\x01\x32\xa7\x01\n)StreamAggregatesSpotExchangeRateServiceV1\x12z\n\tSubscribe\x12\x33.kaikosdk.StreamAggregatesSpotExchangeRateRequestV1\x1a\x34.kaikosdk.StreamAggregatesSpotExchangeRateResponseV1\"\x00\x30\x01\x32\xad\x01\n+StreamAggregatesDirectExchangeRateServiceV1\x12~\n\tSubscribe\x12\x35.kaikosdk.StreamAggregatesDirectExchangeRateRequestV1\x1a\x36.kaikosdk.StreamAggregatesDirectExchangeRateResponseV1\"\x00\x30\x01\x32k\n\x15StreamTradesServiceV1\x12R\n\tSubscribe\x12\x1f.kaikosdk.StreamTradesRequestV1\x1a .kaikosdk.StreamTradesResponseV1\"\x00\x30\x01\x32\x83\x01\n\x1dStreamAggregatesVWAPServiceV1\x12\x62\n\tSubscribe\x12\'.kaikosdk.StreamAggregatesVWAPRequestV1\x1a(.kaikosdk.StreamAggregatesVWAPResponseV1\"\x00\x30\x01\x32v\n\x14StreamIndexServiceV1\x12^\n\tSubscribe\x12%.kaikosdk.StreamIndexServiceRequestV1\x1a&.kaikosdk.StreamIndexServiceResponseV1\"\x00\x30\x01\x32}\n\x1bStreamMarketUpdateServiceV1\x12^\n\tSubscribe\x12%.kaikosdk.StreamMarketUpdateRequestV1\x1a&.kaikosdk.StreamMarketUpdateResponseV1\"\x00\x30\x01\x42W\n\rcom.kaiko.sdkB\x08SdkProtoP\x01Z/github.com/challengerdeep/kaiko-go-sdk;kaikosdk\xaa\x02\x08KaikoSdkb\x06proto3'
  ,
  dependencies=[sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_request__pb2.DESCRIPTOR,sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_response__pb2.DESCRIPTOR,sdk_dot_stream_dot_aggregates__vwap__v1_dot_request__pb2.DESCRIPTOR,sdk_dot_stream_dot_aggregates__vwap__v1_dot_response__pb2.DESCRIPTOR,sdk_dot_stream_dot_aggregates__direct__exchange__rate__v1_dot_request__pb2.DESCRIPTOR,sdk_dot_stream_dot_aggregates__direct__exchange__rate__v1_dot_response__pb2.DESCRIPTOR,sdk_dot_stream_dot_aggregates__spot__exchange__rate__v1_dot_request__pb2.DESCRIPTOR,sdk_dot_stream_dot_aggregates__spot__exchange__rate__v1_dot_response__pb2.DESCRIPTOR,sdk_dot_stream_dot_index__v1_dot_request__pb2.DESCRIPTOR,sdk_dot_stream_dot_index__v1_dot_response__pb2.DESCRIPTOR,sdk_dot_stream_dot_market__update__v1_dot_request__pb2.DESCRIPTOR,sdk_dot_stream_dot_market__update__v1_dot_response__pb2.DESCRIPTOR,sdk_dot_stream_dot_trades__v1_dot_request__pb2.DESCRIPTOR,sdk_dot_stream_dot_trades__v1_dot_response__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_STREAMAGGREGATESOHLCVSERVICEV1 = _descriptor.ServiceDescriptor(
  name='StreamAggregatesOHLCVServiceV1',
  full_name='kaikosdk.StreamAggregatesOHLCVServiceV1',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=685,
  serialized_end=819,
  methods=[
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='kaikosdk.StreamAggregatesOHLCVServiceV1.Subscribe',
    index=0,
    containing_service=None,
    input_type=sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_request__pb2._STREAMAGGREGATESOHLCVREQUESTV1,
    output_type=sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_response__pb2._STREAMAGGREGATESOHLCVRESPONSEV1,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMAGGREGATESOHLCVSERVICEV1)

DESCRIPTOR.services_by_name['StreamAggregatesOHLCVServiceV1'] = _STREAMAGGREGATESOHLCVSERVICEV1


_STREAMAGGREGATESSPOTEXCHANGERATESERVICEV1 = _descriptor.ServiceDescriptor(
  name='StreamAggregatesSpotExchangeRateServiceV1',
  full_name='kaikosdk.StreamAggregatesSpotExchangeRateServiceV1',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=822,
  serialized_end=989,
  methods=[
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='kaikosdk.StreamAggregatesSpotExchangeRateServiceV1.Subscribe',
    index=0,
    containing_service=None,
    input_type=sdk_dot_stream_dot_aggregates__spot__exchange__rate__v1_dot_request__pb2._STREAMAGGREGATESSPOTEXCHANGERATEREQUESTV1,
    output_type=sdk_dot_stream_dot_aggregates__spot__exchange__rate__v1_dot_response__pb2._STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMAGGREGATESSPOTEXCHANGERATESERVICEV1)

DESCRIPTOR.services_by_name['StreamAggregatesSpotExchangeRateServiceV1'] = _STREAMAGGREGATESSPOTEXCHANGERATESERVICEV1


_STREAMAGGREGATESDIRECTEXCHANGERATESERVICEV1 = _descriptor.ServiceDescriptor(
  name='StreamAggregatesDirectExchangeRateServiceV1',
  full_name='kaikosdk.StreamAggregatesDirectExchangeRateServiceV1',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=992,
  serialized_end=1165,
  methods=[
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='kaikosdk.StreamAggregatesDirectExchangeRateServiceV1.Subscribe',
    index=0,
    containing_service=None,
    input_type=sdk_dot_stream_dot_aggregates__direct__exchange__rate__v1_dot_request__pb2._STREAMAGGREGATESDIRECTEXCHANGERATEREQUESTV1,
    output_type=sdk_dot_stream_dot_aggregates__direct__exchange__rate__v1_dot_response__pb2._STREAMAGGREGATESDIRECTEXCHANGERATERESPONSEV1,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMAGGREGATESDIRECTEXCHANGERATESERVICEV1)

DESCRIPTOR.services_by_name['StreamAggregatesDirectExchangeRateServiceV1'] = _STREAMAGGREGATESDIRECTEXCHANGERATESERVICEV1


_STREAMTRADESSERVICEV1 = _descriptor.ServiceDescriptor(
  name='StreamTradesServiceV1',
  full_name='kaikosdk.StreamTradesServiceV1',
  file=DESCRIPTOR,
  index=3,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1167,
  serialized_end=1274,
  methods=[
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='kaikosdk.StreamTradesServiceV1.Subscribe',
    index=0,
    containing_service=None,
    input_type=sdk_dot_stream_dot_trades__v1_dot_request__pb2._STREAMTRADESREQUESTV1,
    output_type=sdk_dot_stream_dot_trades__v1_dot_response__pb2._STREAMTRADESRESPONSEV1,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMTRADESSERVICEV1)

DESCRIPTOR.services_by_name['StreamTradesServiceV1'] = _STREAMTRADESSERVICEV1


_STREAMAGGREGATESVWAPSERVICEV1 = _descriptor.ServiceDescriptor(
  name='StreamAggregatesVWAPServiceV1',
  full_name='kaikosdk.StreamAggregatesVWAPServiceV1',
  file=DESCRIPTOR,
  index=4,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1277,
  serialized_end=1408,
  methods=[
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='kaikosdk.StreamAggregatesVWAPServiceV1.Subscribe',
    index=0,
    containing_service=None,
    input_type=sdk_dot_stream_dot_aggregates__vwap__v1_dot_request__pb2._STREAMAGGREGATESVWAPREQUESTV1,
    output_type=sdk_dot_stream_dot_aggregates__vwap__v1_dot_response__pb2._STREAMAGGREGATESVWAPRESPONSEV1,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMAGGREGATESVWAPSERVICEV1)

DESCRIPTOR.services_by_name['StreamAggregatesVWAPServiceV1'] = _STREAMAGGREGATESVWAPSERVICEV1


_STREAMINDEXSERVICEV1 = _descriptor.ServiceDescriptor(
  name='StreamIndexServiceV1',
  full_name='kaikosdk.StreamIndexServiceV1',
  file=DESCRIPTOR,
  index=5,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1410,
  serialized_end=1528,
  methods=[
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='kaikosdk.StreamIndexServiceV1.Subscribe',
    index=0,
    containing_service=None,
    input_type=sdk_dot_stream_dot_index__v1_dot_request__pb2._STREAMINDEXSERVICEREQUESTV1,
    output_type=sdk_dot_stream_dot_index__v1_dot_response__pb2._STREAMINDEXSERVICERESPONSEV1,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMINDEXSERVICEV1)

DESCRIPTOR.services_by_name['StreamIndexServiceV1'] = _STREAMINDEXSERVICEV1


_STREAMMARKETUPDATESERVICEV1 = _descriptor.ServiceDescriptor(
  name='StreamMarketUpdateServiceV1',
  full_name='kaikosdk.StreamMarketUpdateServiceV1',
  file=DESCRIPTOR,
  index=6,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1530,
  serialized_end=1655,
  methods=[
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='kaikosdk.StreamMarketUpdateServiceV1.Subscribe',
    index=0,
    containing_service=None,
    input_type=sdk_dot_stream_dot_market__update__v1_dot_request__pb2._STREAMMARKETUPDATEREQUESTV1,
    output_type=sdk_dot_stream_dot_market__update__v1_dot_response__pb2._STREAMMARKETUPDATERESPONSEV1,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMMARKETUPDATESERVICEV1)

DESCRIPTOR.services_by_name['StreamMarketUpdateServiceV1'] = _STREAMMARKETUPDATESERVICEV1

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregates_direct_exchange_rate_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import source_data_pb2 as sdk_dot_core_dot_source__data__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/aggregates_direct_exchange_rate_v1/response.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n7com.kaiko.sdk.stream.aggregates_direct_exchange_rate_v1P\001Zsgithub.com/challengerdeep/kaiko-go-sdk/stream/aggregates_direct_exchange_rate_v1;aggregates_direct_exchange_rate_v1\252\002.KaikoSdk.Stream.AggregatesDirectExchangeRateV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<sdk/stream/aggregates_direct_exchange_rate_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1asdk/core/source_data.proto\"\xd6\x01\n,StreamAggregatesDirectExchangeRateResponseV1\x12\x11\n\taggregate\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\r\n\x05price\x18\x03 \x01(\t\x12\x13\n\x0bsequence_id\x18\x04 \x01(\t\x12%\n\x07sources\x18\x05 \x03(\x0b\x32\x14.kaikosdk.SourceData\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03uid\x18\x07 \x01(\tB\xe1\x01\n7com.kaiko.sdk.stream.aggregates_direct_exchange_rate_v1P\x01Zsgithub.com/challengerdeep/kaiko-go-sdk/stream/aggregates_direct_exchange_rate_v1;aggregates_direct_exchange_rate_v1\xaa\x02.KaikoSdk.Stream.AggregatesDirectExchangeRateV1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,sdk_dot_core_dot_source__data__pb2.DESCRIPTOR,])




_STREAMAGGREGATESDIRECTEXCHANGERATERESPONSEV1 = _descriptor.Descriptor(
  name='StreamAggregatesDirectExchangeRateResponseV1',
  full_name='kaikosdk.StreamAggregatesDirectExchangeRateResponseV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aggregate', full_name='kaikosdk.StreamAggregatesDirectExchangeRateResponseV1.aggregate', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='kaikosdk.StreamAggregatesDirectExchangeRateResponseV1.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='kaikosdk.StreamAggregatesDirectExchangeRateResponseV1.price', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_id', full_name='kaikosdk.StreamAggregatesDirectExchangeRateResponseV1.sequence_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sources', full_name='kaikosdk.StreamAggregatesDirectExchangeRateResponseV1.sources', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='kaikosdk.StreamAggregatesDirectExchangeRateResponseV1.timestamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='kaikosdk.StreamAggregatesDirectExchangeRateResponseV1.uid', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=350,
)

_STREAMAGGREGATESDIRECTEXCHANGERATERESPONSEV1.fields_by_name['sources'].message_type = sdk_dot_core_dot_source__data__pb2._SOURCEDATA
_STREAMAGGREGATESDIRECTEXCHANGERATERESPONSEV1.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['StreamAggregatesDirectExchangeRateResponseV1'] = _STREAMAGGREGATESDIRECTEXCHANGERATERESPONSEV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamAggregatesDirectExchangeRateResponseV1 = _reflection.GeneratedProtocolMessageType('StreamAggregatesDirectExchangeRateResponseV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMAGGREGATESDIRECTEXCHANGERATERESPONSEV1,
  '__module__' : 'sdk.stream.aggregates_direct_exchange_rate_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamAggregatesDirectExchangeRateResponseV1)
  })
_sym_db.RegisterMessage(StreamAggregatesDirectExchangeRateResponseV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/market_update_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2
from kaikosdk.core import instrument_criteria_pb2 as sdk_dot_core_dot_instrument__criteria__pb2
from kaikosdk.stream.market_update_v1 import commodity_pb2 as sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/market_update_v1/request.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n%com.kaiko.sdk.stream.market_update_v1P\001ZOgithub.com/challengerdeep/kaiko-go-sdk/stream/market_update_v1;market_update_v1\252\002\036KaikoSdk.Stream.MarketUpdateV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)sdk/stream/market_update_v1/request.proto\x12\x08kaikosdk\x1a\x1csdk/core/data_interval.proto\x1a\"sdk/core/instrument_criteria.proto\x1a+sdk/stream/market_update_v1/commodity.proto\"\xbe\x01\n\x1bStreamMarketUpdateRequestV1\x12\x39\n\x13instrument_criteria\x18\x01 \x01(\x0b\x32\x1c.kaikosdk.InstrumentCriteria\x12:\n\x0b\x63ommodities\x18\x02 \x03(\x0e\x32%.kaikosdk.StreamMarketUpdateCommodity\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataIntervalB\x9b\x01\n%com.kaiko.sdk.stream.market_update_v1P\x01ZOgithub.com/challengerdeep/kaiko-go-sdk/stream/market_update_v1;market_update_v1\xaa\x02\x1eKaikoSdk.Stream.MarketUpdateV1b\x06proto3'
  ,
  dependencies=[sdk_dot_core_dot_data__interval__pb2.DESCRIPTOR,sdk_dot_core_dot_instrument__criteria__pb2.DESCRIPTOR,sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2.DESCRIPTOR,])




_STREAMMARKETUPDATEREQUESTV1 = _descriptor.Descriptor(
  name='StreamMarketUpdateRequestV1',
  full_name='kaikosdk.StreamMarketUpdateRequestV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instrument_criteria', full_name='kaikosdk.StreamMarketUpdateRequestV1.instrument_criteria', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commodities', full_name='kaikosdk.StreamMarketUpdateRequestV1.commodities', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='kaikosdk.StreamMarketUpdateRequestV1.interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=357,
)

_STREAMMARKETUPDATEREQUESTV1.fields_by_name['instrument_criteria'].message_type = sdk_dot_core_dot_instrument__criteria__pb2._INSTRUMENTCRITERIA
_STREAMMARKETUPDATEREQUESTV1.fields_by_name['commodities'].enum_type = sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2._STREAMMARKETUPDATECOMMODITY
_STREAMMARKETUPDATEREQUESTV1.fields_by_name['interval'].message_type = sdk_dot_core_dot_data__interval__pb2._DATAINTERVAL
DESCRIPTOR.message_types_by_name['StreamMarketUpdateRequestV1'] = _STREAMMARKETUPDATEREQUESTV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamMarketUpdateRequestV1 = _reflection.GeneratedProtocolMessageType('StreamMarketUpdateRequestV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMMARKETUPDATEREQUESTV1,
  '__module__' : 'sdk.stream.market_update_v1.request_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamMarketUpdateRequestV1)
  })
_sym_db.RegisterMessage(StreamMarketUpdateRequestV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/core/data_interval.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/core/data_interval.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\022com.kaiko.sdk.coreP\001Z0github.com/challengerdeep/kaiko-go-sdk/core;core\252\002\rKaikoSdk.Core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1csdk/core/data_interval.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\"l\n\x0c\x44\x61taInterval\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBX\n\x12\x63om.kaiko.sdk.coreP\x01Z0github.com/challengerdeep/kaiko-go-sdk/core;core\xaa\x02\rKaikoSdk.Coreb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_DATAINTERVAL = _descriptor.Descriptor(
  name='DataInterval',
  full_name='kaikosdk.DataInterval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time', full_name='kaikosdk.DataInterval.start_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='kaikosdk.DataInterval.end_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=183,
)

_DATAINTERVAL.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DATAINTERVAL.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['DataInterval'] = _DATAINTERVAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataInterval = _reflection.GeneratedProtocolMessageType('DataInterval', (_message.Message,), {
  'DESCRIPTOR' : _DATAINTERVAL,
  '__module__' : 'sdk.core.data_interval_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.DataInterval)
  })
_sym_db.RegisterMessage(DataInterval)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/index_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/index_v1/response.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\035com.kaiko.sdk.stream.index_v1P\001Z?github.com/challengerdeep/kaiko-go-sdk/stream/index_v1;index_v1\252\002\027KaikoSdk.Stream.IndexV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"sdk/stream/index_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1csdk/core/data_interval.proto\"\x83\x01\n$StreamIndexServiceResponsePercentage\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x38\n\x05pairs\x18\x03 \x03(\x0b\x32).kaikosdk.StreamIndexServiceResponsePairs\"\x85\x01\n\x1fStreamIndexServiceResponsePairs\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x12\x44\n\x0binstruments\x18\x03 \x03(\x0b\x32/.kaikosdk.StreamIndexServiceResponseInstruments\"X\n%StreamIndexServiceResponseInstruments\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x01\"\xe3\x01\n\x1cStreamIndexServiceResponseV1\x12\x12\n\nindex_code\x18\x01 \x01(\t\x12\x12\n\nevent_type\x18\x02 \x01(\t\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataInterval\x12\x43\n\x0bpercentages\x18\x04 \x03(\x0b\x32..kaikosdk.StreamIndexServiceResponsePercentage\x12,\n\x08ts_event\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB|\n\x1d\x63om.kaiko.sdk.stream.index_v1P\x01Z?github.com/challengerdeep/kaiko-go-sdk/stream/index_v1;index_v1\xaa\x02\x17KaikoSdk.Stream.IndexV1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,sdk_dot_core_dot_data__interval__pb2.DESCRIPTOR,])




_STREAMINDEXSERVICERESPONSEPERCENTAGE = _descriptor.Descriptor(
  name='StreamIndexServiceResponsePercentage',
  full_name='kaikosdk.StreamIndexServiceResponsePercentage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='percentage', full_name='kaikosdk.StreamIndexServiceResponsePercentage.percentage', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='kaikosdk.StreamIndexServiceResponsePercentage.price', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pairs', full_name='kaikosdk.StreamIndexServiceResponsePercentage.pairs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=243,
)


_STREAMINDEXSERVICERESPONSEPAIRS = _descriptor.Descriptor(
  name='StreamIndexServiceResponsePairs',
  full_name='kaikosdk.StreamIndexServiceResponsePairs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pair', full_name='kaikosdk.StreamIndexServiceResponsePairs.pair', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='kaikosdk.StreamIndexServiceResponsePairs.weight', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instruments', full_name='kaikosdk.StreamIndexServiceResponsePairs.instruments', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=246,
  serialized_end=379,
)


_STREAMINDEXSERVICERESPONSEINSTRUMENTS = _descriptor.Descriptor(
  name='StreamIndexServiceResponseInstruments',
  full_name='kaikosdk.StreamIndexServiceResponseInstruments',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange', full_name='kaikosdk.StreamIndexServiceResponseInstruments.exchange', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='kaikosdk.StreamIndexServiceResponseInstruments.price', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='kaikosdk.StreamIndexServiceResponseInstruments.volume', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=381,
  serialized_end=469,
)


_STREAMINDEXSERVICERESPONSEV1 = _descriptor.Descriptor(
  name='StreamIndexServiceResponseV1',
  full_name='kaikosdk.StreamIndexServiceResponseV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index_code', full_name='kaikosdk.StreamIndexServiceResponseV1.index_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='kaikosdk.StreamIndexServiceResponseV1.event_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='kaikosdk.StreamIndexServiceResponseV1.interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentages', full_name='kaikosdk.StreamIndexServiceResponseV1.percentages', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_event', full_name='kaikosdk.StreamIndexServiceResponseV1.ts_event', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=472,
  serialized_end=699,
)

_STREAMINDEXSERVICERESPONSEPERCENTAGE.fields_by_name['pairs'].message_type = _STREAMINDEXSERVICERESPONSEPAIRS
_STREAMINDEXSERVICERESPONSEPAIRS.fields_by_name['instruments'].message_type = _STREAMINDEXSERVICERESPONSEINSTRUMENTS
_STREAMINDEXSERVICERESPONSEV1.fields_by_name['interval'].message_type = sdk_dot_core_dot_data__interval__pb2._DATAINTERVAL
_STREAMINDEXSERVICERESPONSEV1.fields_by_name['percentages'].message_type = _STREAMINDEXSERVICERESPONSEPERCENTAGE
_STREAMINDEXSERVICERESPONSEV1.fields_by_name['ts_event'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['StreamIndexServiceResponsePercentage'] = _STREAMINDEXSERVICERESPONSEPERCENTAGE
DESCRIPTOR.message_types_by_name['StreamIndexServiceResponsePairs'] = _STREAMINDEXSERVICERESPONSEPAIRS
DESCRIPTOR.message_types_by_name['StreamIndexServiceResponseInstruments'] = _STREAMINDEXSERVICERESPONSEINSTRUMENTS
DESCRIPTOR.message_types_by_name['StreamIndexServiceResponseV1'] = _STREAMINDEXSERVICERESPONSEV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamIndexServiceResponsePercentage = _reflection.GeneratedProtocolMessageType('StreamIndexServiceResponsePercentage', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINDEXSERVICERESPONSEPERCENTAGE,
  '__module__' : 'sdk.stream.index_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamIndexServiceResponsePercentage)
  })
_sym_db.RegisterMessage(StreamIndexServiceResponsePercentage)

StreamIndexServiceResponsePairs = _reflection.GeneratedProtocolMessageType('StreamIndexServiceResponsePairs', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINDEXSERVICERESPONSEPAIRS,
  '__module__' : 'sdk.stream.index_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamIndexServiceResponsePairs)
  })
_sym_db.RegisterMessage(StreamIndexServiceResponsePairs)

StreamIndexServiceResponseInstruments = _reflection.GeneratedProtocolMessageType('StreamIndexServiceResponseInstruments', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINDEXSERVICERESPONSEINSTRUMENTS,
  '__module__' : 'sdk.stream.index_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamIndexServiceResponseInstruments)
  })
_sym_db.RegisterMessage(StreamIndexServiceResponseInstruments)

StreamIndexServiceResponseV1 = _reflection.GeneratedProtocolMessageType('StreamIndexServiceResponseV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINDEXSERVICERESPONSEV1,
  '__module__' : 'sdk.stream.index_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamIndexServiceResponseV1)
  })
_sym_db.RegisterMessage(StreamIndexServiceResponseV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/core/envelope_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/core/envelope_status.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\022com.kaiko.sdk.coreP\001Z0github.com/challengerdeep/kaiko-go-sdk/core;core\252\002\rKaikoSdk.Core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1esdk/core/envelope_status.proto\x12\x08kaikosdk*5\n\x0e\x45nvelopeStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x42X\n\x12\x63om.kaiko.sdk.coreP\x01Z0github.com/challengerdeep/kaiko-go-sdk/core;core\xaa\x02\rKaikoSdk.Coreb\x06proto3'
)

_ENVELOPESTATUS = _descriptor.EnumDescriptor(
  name='EnvelopeStatus',
  full_name='kaikosdk.EnvelopeStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=44,
  serialized_end=97,
)
_sym_db.RegisterEnumDescriptor(_ENVELOPESTATUS)

EnvelopeStatus = enum_type_wrapper.EnumTypeWrapper(_ENVELOPESTATUS)
UNKNOWN = 0
ERROR = 1
SUCCESS = 2


DESCRIPTOR.enum_types_by_name['EnvelopeStatus'] = _ENVELOPESTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/core/source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import source_data_pb2 as sdk_dot_core_dot_source__data__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/core/source.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\022com.kaiko.sdk.coreP\001Z0github.com/challengerdeep/kaiko-go-sdk/core;core\252\002\rKaikoSdk.Core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15sdk/core/source.proto\x12\x08kaikosdk\x1a\x1asdk/core/source_data.proto\";\n\x06Source\x12\"\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x14.kaikosdk.SourceData\x12\r\n\x05price\x18\x02 \x01(\tBX\n\x12\x63om.kaiko.sdk.coreP\x01Z0github.com/challengerdeep/kaiko-go-sdk/core;core\xaa\x02\rKaikoSdk.Coreb\x06proto3'
  ,
  dependencies=[sdk_dot_core_dot_source__data__pb2.DESCRIPTOR,])




_SOURCE = _descriptor.Descriptor(
  name='Source',
  full_name='kaikosdk.Source',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='kaikosdk.Source.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='kaikosdk.Source.price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=122,
)

_SOURCE.fields_by_name['data'].message_type = sdk_dot_core_dot_source__data__pb2._SOURCEDATA
DESCRIPTOR.message_types_by_name['Source'] = _SOURCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Source = _reflection.GeneratedProtocolMessageType('Source', (_message.Message,), {
  'DESCRIPTOR' : _SOURCE,
  '__module__' : 'sdk.core.source_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.Source)
  })
_sym_db.RegisterMessage(Source)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/trades_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import wrappers_pb2 as sdk_dot_core_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/trades_v1/response.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\036com.kaiko.sdk.stream.trades_v1P\001ZAgithub.com/challengerdeep/kaiko-go-sdk/stream/trades_v1;trades_v1\252\002\030KaikoSdk.Stream.TradesV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#sdk/stream/trades_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17sdk/core/wrappers.proto\"\x94\x04\n\x16StreamTradesResponseV1\x12Y\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32:.kaikosdk.StreamTradesResponseV1.AdditionalPropertiesEntry\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\r\n\x05\x63lass\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x10\n\x08\x65xchange\x18\x05 \x01(\t\x12\x13\n\x0bsequence_id\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\r\n\x05price\x18\x08 \x01(\x01\x12\x38\n\x04side\x18\t \x01(\x0e\x32*.kaikosdk.StreamTradesResponseV1.TradeSide\x12-\n\x0bts_exchange\x18\n \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12/\n\rts_collection\x18\x0b \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12,\n\x08ts_event\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\tTradeSide\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03\x42UY\x10\x01\x12\x08\n\x04SELL\x10\x02\x42\x80\x01\n\x1e\x63om.kaiko.sdk.stream.trades_v1P\x01ZAgithub.com/challengerdeep/kaiko-go-sdk/stream/trades_v1;trades_v1\xaa\x02\x18KaikoSdk.Stream.TradesV1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,sdk_dot_core_dot_wrappers__pb2.DESCRIPTOR,])



_STREAMTRADESRESPONSEV1_TRADESIDE = _descriptor.EnumDescriptor(
  name='TradeSide',
  full_name='kaikosdk.StreamTradesResponseV1.TradeSide',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SELL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=597,
  serialized_end=640,
)
_sym_db.RegisterEnumDescriptor(_STREAMTRADESRESPONSEV1_TRADESIDE)


_STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY = _descriptor.Descriptor(
  name='AdditionalPropertiesEntry',
  full_name='kaikosdk.StreamTradesResponseV1.AdditionalPropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='kaikosdk.StreamTradesResponseV1.AdditionalPropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='kaikosdk.StreamTradesResponseV1.AdditionalPropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=595,
)

_STREAMTRADESRESPONSEV1 = _descriptor.Descriptor(
  name='StreamTradesResponseV1',
  full_name='kaikosdk.StreamTradesResponseV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='additional_properties', full_name='kaikosdk.StreamTradesResponseV1.additional_properties', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='kaikosdk.StreamTradesResponseV1.amount', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class', full_name='kaikosdk.StreamTradesResponseV1.class', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='kaikosdk.StreamTradesResponseV1.code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='kaikosdk.StreamTradesResponseV1.exchange', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_id', full_name='kaikosdk.StreamTradesResponseV1.sequence_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='kaikosdk.StreamTradesResponseV1.id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='kaikosdk.StreamTradesResponseV1.price', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='side', full_name='kaikosdk.StreamTradesResponseV1.side', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_exchange', full_name='kaikosdk.StreamTradesResponseV1.ts_exchange', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_collection', full_name='kaikosdk.StreamTradesResponseV1.ts_collection', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_event', full_name='kaikosdk.StreamTradesResponseV1.ts_event', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY, ],
  enum_types=[
    _STREAMTRADESRESPONSEV1_TRADESIDE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=640,
)

_STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY.containing_type = _STREAMTRADESRESPONSEV1
_STREAMTRADESRESPONSEV1.fields_by_name['additional_properties'].message_type = _STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY
_STREAMTRADESRESPONSEV1.fields_by_name['side'].enum_type = _STREAMTRADESRESPONSEV1_TRADESIDE
_STREAMTRADESRESPONSEV1.fields_by_name['ts_exchange'].message_type = sdk_dot_core_dot_wrappers__pb2._TIMESTAMPVALUE
_STREAMTRADESRESPONSEV1.fields_by_name['ts_collection'].message_type = sdk_dot_core_dot_wrappers__pb2._TIMESTAMPVALUE
_STREAMTRADESRESPONSEV1.fields_by_name['ts_event'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMTRADESRESPONSEV1_TRADESIDE.containing_type = _STREAMTRADESRESPONSEV1
DESCRIPTOR.message_types_by_name['StreamTradesResponseV1'] = _STREAMTRADESRESPONSEV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamTradesResponseV1 = _reflection.GeneratedProtocolMessageType('StreamTradesResponseV1', (_message.Message,), {

  'AdditionalPropertiesEntry' : _reflection.GeneratedProtocolMessageType('AdditionalPropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY,
    '__module__' : 'sdk.stream.trades_v1.response_pb2'
    # @@protoc_insertion_point(class_scope:kaikosdk.StreamTradesResponseV1.AdditionalPropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _STREAMTRADESRESPONSEV1,
  '__module__' : 'sdk.stream.trades_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamTradesResponseV1)
  })
_sym_db.RegisterMessage(StreamTradesResponseV1)
_sym_db.RegisterMessage(StreamTradesResponseV1.AdditionalPropertiesEntry)


DESCRIPTOR._options = None
_STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/core/source_data.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/core/source_data.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\022com.kaiko.sdk.coreP\001Z0github.com/challengerdeep/kaiko-go-sdk/core;core\252\002\rKaikoSdk.Core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1asdk/core/source_data.proto\x12\x08kaikosdk\"Q\n\nSourceData\x12\x15\n\rexchange_code\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x12\r\n\x05price\x18\x03 \x01(\t\x12\x0e\n\x06volume\x18\x04 \x01(\tBX\n\x12\x63om.kaiko.sdk.coreP\x01Z0github.com/challengerdeep/kaiko-go-sdk/core;core\xaa\x02\rKaikoSdk.Coreb\x06proto3'
)




_SOURCEDATA = _descriptor.Descriptor(
  name='SourceData',
  full_name='kaikosdk.SourceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_code', full_name='kaikosdk.SourceData.exchange_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='kaikosdk.SourceData.count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='kaikosdk.SourceData.price', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='kaikosdk.SourceData.volume', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=121,
)

DESCRIPTOR.message_types_by_name['SourceData'] = _SOURCEDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SourceData = _reflection.GeneratedProtocolMessageType('SourceData', (_message.Message,), {
  'DESCRIPTOR' : _SOURCEDATA,
  '__module__' : 'sdk.core.source_data_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.SourceData)
  })
_sym_db.RegisterMessage(SourceData)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/core/envelope.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import envelope_status_pb2 as sdk_dot_core_dot_envelope__status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/core/envelope.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\022com.kaiko.sdk.coreP\001Z0github.com/challengerdeep/kaiko-go-sdk/core;core\252\002\rKaikoSdk.Core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17sdk/core/envelope.proto\x12\x08kaikosdk\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1esdk/core/envelope_status.proto\"\xd3\x01\n\x08\x45nvelope\x12\'\n\x06\x61\x63\x63\x65ss\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07message\x18\x02 \x01(\t\x12&\n\x05query\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x06status\x18\x04 \x01(\x0e\x32\x18.kaikosdk.EnvelopeStatus\x12(\n\x04time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\ttimestamp\x18\x06 \x01(\tBX\n\x12\x63om.kaiko.sdk.coreP\x01Z0github.com/challengerdeep/kaiko-go-sdk/core;core\xaa\x02\rKaikoSdk.Coreb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,sdk_dot_core_dot_envelope__status__pb2.DESCRIPTOR,])




_ENVELOPE = _descriptor.Descriptor(
  name='Envelope',
  full_name='kaikosdk.Envelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access', full_name='kaikosdk.Envelope.access', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='kaikosdk.Envelope.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='kaikosdk.Envelope.query', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='kaikosdk.Envelope.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='kaikosdk.Envelope.time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='kaikosdk.Envelope.timestamp', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=344,
)

_ENVELOPE.fields_by_name['access'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ENVELOPE.fields_by_name['query'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ENVELOPE.fields_by_name['status'].enum_type = sdk_dot_core_dot_envelope__status__pb2._ENVELOPESTATUS
_ENVELOPE.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Envelope'] = _ENVELOPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Envelope = _reflection.GeneratedProtocolMessageType('Envelope', (_message.Message,), {
  'DESCRIPTOR' : _ENVELOPE,
  '__module__' : 'sdk.core.envelope_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.Envelope)
  })
_sym_db.RegisterMessage(Envelope)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/market_update_v1/commodity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/market_update_v1/commodity.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n%com.kaiko.sdk.stream.market_update_v1P\001ZOgithub.com/challengerdeep/kaiko-go-sdk/stream/market_update_v1;market_update_v1\252\002\036KaikoSdk.Stream.MarketUpdateV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+sdk/stream/market_update_v1/commodity.proto\x12\x08kaikosdk*o\n\x1bStreamMarketUpdateCommodity\x12\x10\n\x0cSMUC_UNKNOWN\x10\x00\x12\x0e\n\nSMUC_TRADE\x10\x01\x12\x14\n\x10SMUC_TOP_OF_BOOK\x10\x02\x12\x18\n\x14SMUC_FULL_ORDER_BOOK\x10\x03\x42\x9b\x01\n%com.kaiko.sdk.stream.market_update_v1P\x01ZOgithub.com/challengerdeep/kaiko-go-sdk/stream/market_update_v1;market_update_v1\xaa\x02\x1eKaikoSdk.Stream.MarketUpdateV1b\x06proto3'
)

_STREAMMARKETUPDATECOMMODITY = _descriptor.EnumDescriptor(
  name='StreamMarketUpdateCommodity',
  full_name='kaikosdk.StreamMarketUpdateCommodity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SMUC_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMUC_TRADE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMUC_TOP_OF_BOOK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMUC_FULL_ORDER_BOOK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57,
  serialized_end=168,
)
_sym_db.RegisterEnumDescriptor(_STREAMMARKETUPDATECOMMODITY)

StreamMarketUpdateCommodity = enum_type_wrapper.EnumTypeWrapper(_STREAMMARKETUPDATECOMMODITY)
SMUC_UNKNOWN = 0
SMUC_TRADE = 1
SMUC_TOP_OF_BOOK = 2
SMUC_FULL_ORDER_BOOK = 3


DESCRIPTOR.enum_types_by_name['StreamMarketUpdateCommodity'] = _STREAMMARKETUPDATECOMMODITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
